@@ -1,11 +1,10 @@
-import os
-from fastapi import APIRouter
-import httpx
 import asyncio
-from typing import Dict, Any
-import aiomysql
-from aiokafka import AIOKafkaProducer
 import logging
+from typing import Any, Dict
+
+import httpx
+from aiokafka import AIOKafkaProducer
+from fastapi import APIRouter
 
 router = APIRouter(tags=["health"])
 
@@ -26,8 +25,7 @@ async def system_info():
         "flink_job_manager": await check_flink_job_manager(),
         "flink_sql_gateway": await check_flink_sql_gateway(),
         "kafka": await check_kafka(),
-        "mariadb": await check_mariadb(),
-        "minio": await check_minio(),
+        "jupyterlab": await check_jupyterlab(),
     }
 
     # Overall system status
@@ -97,42 +95,27 @@ async def check_kafka() -> Dict[str, Any]:
         return {"status": "unhealthy", "endpoint": "localhost:9092", "error": str(e)}
 
 
-async def check_mariadb() -> Dict[str, Any]:
-    """Check MariaDB health at localhost:3306"""
+async def check_jupyterlab() -> Dict[str, Any]:
+    """Check JupyterLab health at http://localhost:8888"""
     try:
-        mysql_password = os.getenv("MYSQL_RESINKIT_PASSWORD", "inspect_mariadb")
-        connection = await aiomysql.connect(host="localhost", port=3306, user="resinkit", password=mysql_password, db="flink", connect_timeout=5)
-
-        async with connection.cursor() as cursor:
-            await cursor.execute("SELECT VERSION()")
-            version = await cursor.fetchone()
-            await cursor.execute("SELECT COUNT(*) as table_count FROM information_schema.tables WHERE table_schema = 'flink'")
-            table_count = await cursor.fetchone()
-
-        connection.close()
-
-        return {
-            "status": "healthy",
-            "endpoint": "localhost:3306",
-            "details": {"version": version[0] if version else "unknown", "database": "flink", "table_count": table_count[0] if table_count else 0},
-        }
-    except Exception as e:
-        return {"status": "unhealthy", "endpoint": "localhost:3306", "error": str(e)}
-
-
-async def check_minio() -> Dict[str, Any]:
-    """Check MinIO health at http://127.0.0.1:9000"""
-    try:
-        health_url = "http://127.0.0.1:9000/minio/health/live"
-        # Check MinIO health endpoint
         async with httpx.AsyncClient(timeout=5.0) as client:
-            response = await client.get(health_url)
+            response = await client.get("http://localhost:8888/api/status")
             if response.status_code == 200:
-                return {"status": "healthy", "endpoint": "http://127.0.0.1:9000", "details": {"health_check": "passed", "credentials": "not_verified"}}
+                data = response.json()
+                return {
+                    "status": "healthy",
+                    "endpoint": "http://localhost:8888",
+                    "details": {
+                        "started": data.get("started"),
+                        "last_activity": data.get("last_activity"),
+                        "kernels": data.get("kernels", 0),
+                        "connections": data.get("connections", 0),
+                    },
+                }
             else:
-                return {"status": "unhealthy", "endpoint": "http://127.0.0.1:9000", "error": f"Health check failed: HTTP {response.status_code}"}
+                return {"status": "unhealthy", "endpoint": "http://localhost:8888", "error": f"HTTP {response.status_code}"}
     except Exception as e:
-        return {"status": "unhealthy", "endpoint": "http://127.0.0.1:9000", "error": str(e)}
+        return {"status": "unhealthy", "endpoint": "http://localhost:8888", "error": str(e)}
 
 
 # Add other existing endpoints here if any
