@@ -1,8 +1,10 @@
-from fastapi import APIRouter, Header, HTTPException
-from typing import Optional, Dict, Any
-from resinkit_api.core.config import settings
-import httpx
 import time
+from typing import Any, Dict, Optional
+
+import httpx
+from fastapi import APIRouter, Header, HTTPException
+
+from resinkit_api.core.config import settings
 from resinkit_api.core.logging import get_logger
 
 logger = get_logger(__name__)
