@@ -1,6 +1,7 @@
 import os
-from typing import Union
 from functools import cached_property
+from pathlib import Path
+from typing import Union
 
 from pydantic import (
     BaseModel,
@@ -10,7 +11,6 @@ from pydantic_settings import BaseSettings, SettingsConfigDict
 
 from resinkit_api.core.find_root import find_project_root
 
-
 _CURRENT_ENV = os.getenv("ENV", "dev")
 
 
@@ -62,6 +62,8 @@ class Settings(BaseSettings):
 
     ##### Database #####
     DB_PATH: str = "_data_/sqlite.db"
+    DOT_RKS_PATH: str = "_data_/.rsk"
+    SQLITE_FOLDER: str = "_data_/"
     SQLALCHEMY_ECHO: Union[bool, str] = False
 
     VARIABLE_ENCRYPTION_KEY: str = "resinkit-default-encryption-key-0519"
@@ -75,5 +77,16 @@ class Settings(BaseSettings):
         db_path.parent.mkdir(parents=True, exist_ok=True)
         return f"sqlite:///{db_path}"
 
+    @cached_property
+    def RKS_PATH(self) -> Path:
+        project_root = find_project_root()
+        return project_root / self.DOT_RKS_PATH
+
+    @cached_property
+    def SQLITE_FOLDER_PATH(self) -> Path:
+        sqlite_folder_path = Path(self.SQLITE_FOLDER)
+        sqlite_folder_path.mkdir(parents=True, exist_ok=True)
+        return sqlite_folder_path
+
 
 settings = Settings()
