@@ -1,23 +1,23 @@
 # Flink CDC Pipeline Runner
 import asyncio
 import os
-import yaml
 import re
-from typing import Any, Dict, List, Optional
 from datetime import UTC, datetime
+from typing import Any, Dict, List, Optional
+
+import yaml
 
 from resinkit_api.clients.job_manager.flink_job_manager_client import FlinkJobManager
-from resinkit_api.utils.resource_manager import get_resource_manager
-from resinkit_api.clients.sql_gateway.flink_sql_gateway_client import FlinkSqlGatewayClient
 from resinkit_api.core.config import settings
 from resinkit_api.core.logging import get_logger
 from resinkit_api.db.models import Task, TaskStatus
-from resinkit_api.services.agent.flink.flink_resource_manager import FlinkResourceManager, FlinkResourcesResult
-from resinkit_api.services.agent.flink.flink_cdc_pipeline_task import FlinkCdcPipelineTask
-from resinkit_api.services.agent.task_base import TaskBase
-from resinkit_api.services.agent.task_runner_base import TaskRunnerBase, LogEntry
-from resinkit_api.services.agent.data_models import TaskExecutionError, FlinkJobStatus, map_flink_status_to_task_status
 from resinkit_api.services.agent.common.log_file_manager import LogFileManager
+from resinkit_api.services.agent.data_models import FlinkJobStatus, TaskExecutionError, map_flink_status_to_task_status
+from resinkit_api.services.agent.flink.flink_cdc_pipeline_task import FlinkCdcPipelineTask
+from resinkit_api.services.agent.flink.flink_resource_manager import FlinkResourceManager, FlinkResourcesResult
+from resinkit_api.services.agent.task_base import TaskBase
+from resinkit_api.services.agent.task_runner_base import LogEntry, TaskRunnerBase
+from resinkit_api.utils.resource_manager import get_resource_manager
 
 logger = get_logger(__name__)
 
@@ -25,20 +25,18 @@ logger = get_logger(__name__)
 class FlinkCdcPipelineRunner(TaskRunnerBase):
     """Runner for executing Flink CDC pipeline jobs."""
 
-    def __init__(self, job_manager: FlinkJobManager, sql_gateway_client: FlinkSqlGatewayClient, runtime_env: dict | None = None):
+    def __init__(self, job_manager: FlinkJobManager, runtime_env: dict | None = None):
         """
         Initialize the Flink CDC Pipeline Runner.
 
         Args:
             job_manager: FlinkJobManager instance for job management
-            sql_gateway_client: FlinkSqlGatewayClient instance (not used for CDC but kept for consistency)
             runtime_env: Optional runtime environment configuration
         """
         super().__init__(runtime_env or {})
         self.flink_home = settings.FLINK_HOME
         self.tasks: Dict[str, FlinkCdcPipelineTask] = {}
         self.job_manager = job_manager
-        self.sql_gateway_client = sql_gateway_client
         self.resource_manager = FlinkResourceManager()
         self._temp_dirs = []  # Track temporary directories for cleanup
 
@@ -328,6 +326,9 @@ class FlinkCdcPipelineRunner(TaskRunnerBase):
         task_statuses: list[TaskStatus] = []
         job_statuses: list[FlinkJobStatus] = []
 
+        # Get previous job results to compare for changes
+        previous_job_results = task.result_summary.get("job_results", {})
+
         # Fetch status for all jobs
         for job_id in job_ids:
             if not job_id:  # Skip None/empty job IDs
@@ -360,7 +361,11 @@ class FlinkCdcPipelineRunner(TaskRunnerBase):
                     }
                     task_statuses.append(task_status)
                     job_statuses.append(flink_status)
-                    lfm.info(f"Job {job_id} status: {flink_status.value} -> {task_status.value}")
+
+                    # Only log if status changed from previous check
+                    previous_status = previous_job_results.get(job_id, {}).get("status")
+                    if previous_status != flink_status.value:
+                        lfm.info(f"Job {job_id} status changed: {previous_status or 'UNKNOWN'} -> {flink_status.value} -> {task_status.value}")
                 else:
                     lfm.warning(f"Could not fetch details for job {job_id}")
                     # Job not found, assume it completed or was cleaned up
