@@ -1,8 +1,8 @@
-from typing import Any, Optional, List, Dict
+from typing import Any, Dict, List, Optional
 
 from resinkit_api.db.models import Task, TaskStatus
-from resinkit_api.services.agent.task_base import TaskBase
 from resinkit_api.services.agent.data_models import LogEntry
+from resinkit_api.services.agent.task_base import TaskBase
 
 
 class TaskRunnerBase:
